Fruitful functions
::::::::::::::::::::::::::::

.. toctree::
   :maxdepth: 3

   returnvalues.rst
   programdevelopment.rst
   composition.rst
   overloading.rst 
   booleanvalues.rst
   booleanvariables.rst
   logicaloperators.rst
   boolfunctions.rst
   returningfrommain.rst
   morerecursion.rst
   leapoffaith.rst
   onemoreexample.rst
   glossary.rst
   Exercises.rst
   mixed_up_code.rst
   coding_practice.rst
